/*\
 *  IMandel.Rexx V1.0
 *   Generates the mandelbrot set into the primary buffer.
 *
 *   Written By: Ian Smith / 27 Gibson St / North East, PA 16428
 *               Usenet: IanSmith@moose.erie.net
 *               Usenet backup: IanSmith@psu.edu
 *               Web: http://moose.erie.net/~iansmith/
 *               Digital Matrix BBS (814) 825-3783 FIDO: 1:2601/564.0
 *
 *  Not the fastest, but decent with an FPU.  Default settings at
 *  lo-res on a A3000 take about 30 seconds. Your milage may vary.
 *  Color Derivitave, Relief and Shadowed Elevations are interesting
 *  operations to try on Mandelbrot sets.  Use the defaults at 640-400
 *  for a sharper image and process from there. :-)
 *
 *  Be sure to use the correct (68000/FP) version of the binary!
 *
\*/                            /* Looks good using standard Amiga modes   */
                               /* When adjusting, the outer circle should */
DefCords="-2.1 2.1 -1.6 1.6"   /* Look like a circle to keep the aspect.  */
CmdName="IMandel"
CmdPath=""

If ~Show('L',"rexxsupport.library") Then
 If ~AddLib("rexxsupport.library",0,-30,0) Then
  Error('Can not find "rexxsupport.library"!')

If Exists("CMPI:"CmdName) Then        /* This should find the executable */
 CmdPath="CMPI:"CmdName               /* no matter where its hiding!     */
Else If Exists("C:"CmdName) Then
 CmdPath="C:"CmdName
Else If Exists("REXX:"CmdName) Then
 CmdPath="REXX:"CmdName
Else If Exists("RXPI:"CmdName) Then
 CmdPath="RXPI:"CmdName
Else If Exists("Rexx:picmdpath") Then
 If Open(In,"Rexx:picmdpath","R") Then Do
  CmdPath=ReadLn(In)||CmdName
  Call Close(In)
 End
If ~Exists(CmdPath) Then
 DispError("I can't find the IMandel executable!")

Options Results
Address("IM_Port")
'current'
Parse Var Result BName ',' BNumber ',' .
BName="IMandel$"||BName
Call GetClipValues()
'tofront'
'askstring "Min_X  Max_X  Min_Y  Max_Y" "'Cords'"'
Cords=Result
If Cords="" Then
 Cords=DefCords
If Words(Cords)~=4 Then
 DispError("You must supply four numbers! Leave blank for defaults.")
If Length(Strip(Translate(Cords,Copies(' ',12),'0123456789-.')))~=0 Then
 DispError("Only numbers allowed.")
If Word(Cords,1)>Word(Cords,2) Then
 DispError("Min_X must be less than Max_X!")
If Word(Cords,3)>Word(Cords,4) Then
 DispError("Min_Y must be less than Max_Y!")
'askprop "Maximum iterations "' MaxIter '1 1000'
MaxIter=Result
'gadgets "Altitude","Mapping","Red/Green","Crossfade","Red/Blue","Crossfade"'
ColorType=result
If ColorType=0 Then
 exit
If ColorType=2 | ColorType=3 Then Do
 'askprop "Red multiplier"' Arg1 '1 255'
 Arg1=Result
 If ColorType=2 Then
  'askprop "Green multiplier"' Arg2 '0 255'
 If ColorType=3 Then
  'askprop "Blue multiplier"' Arg2 '0 255'
 Arg2=Result
End
'askprop "Color step "' ColorStep '1 255'
ColorStep=Result
'gadgets "Entire","Image","Previous","Mask","Custom","Mask"'
MaskType=Result
If MaskType=0 Then
 exit
If MaskType=1 Then
 'entire'
If MaskType=3 Then
 'area'

'jackin'
jacker = Result
'backuptoundo'
'lockimage' BNumber
Call SetClip(BName,MaxIter||'0'x||ColorStep||'0'x||Cords||'0'x||Arg1||'0'x||Arg2)
ElapsedTime=Time('S')
If ColorType>1 Then
 Address Command ''CmdPath||" "||Jacker||" "||MaxIter||" "||ColorStep||" "||Cords||" "||ColorType||" "||Arg1||" "||Arg2
Else
 Address Command ''CmdPath||" "||Jacker||" "||MaxIter||" "||ColorStep||" "||Cords
'unlockimage' BNumber
Address("IM_Port")
'redraw'
Exit 0

DispError:
 Parse Arg Message
 Address("IM_Port")
 'message "'Message'"'
 Exit 10
Return

GetClipValues:
 TempVar=GetClip(BName)
 Parse Var TempVar MaxIter '0'x ColorStep '0'x Cords '0'x Arg1 '0'x Arg2
 If MaxIter="" Then
  MaxIter=100
 If MaxIter<1 | MaxIter>1000 Then
  MaxIter=100
 If ColorStep="" Then
  ColorStep=32
 If ColorStep<1 | ColorStep>255 Then
  ColorStep=32
 If Length(Strip(Translate(Cords,Copies(' ',12),'0123456789-.')))~=0 | Cords="" Then
  Cords=DefCords
 If Arg1="" Then
 If Arg1<1 | Arg1>255 Then
  Arg1=42
 If Arg2="" Then
  Arg2=42
 If Arg1<1 | Arg1>255 Then
  Arg2=42
Return
